let clockInfo = {
    radius: 100,
    width: 0,
    height: 0,
    hour: 0,
    minute: 0,
    canvas: null,
    ctx: null
};


/* Utility function to convert degrees to radians */
function toRadians(deg) { return Math.PI * deg / 180.0; }


// Initial setup
function setupClock(hour, minute) {
    clockInfo.canvas = el("ccanvas");
    clockInfo.ctx = clockInfo.canvas.getContext("2d");
    clockInfo.width = clockInfo.canvas.width;
    clockInfo.height = clockInfo.canvas.height;
    clockInfo.hour = hour;
    clockInfo.minute = minute;
}

/*
    Draw a clock hand of the given length at the given angle
*/
function hand(len, angle)
{
    let ctx = clockInfo.ctx;
    var x = len * Math.cos(toRadians(angle));
    var y = len * Math.sin(toRadians(angle));
    ctx.beginPath();
    ctx.moveTo(clockInfo.width / 2, clockInfo.width / 2);
    ctx.lineTo(clockInfo.width / 2 + x, clockInfo.height / 2 + y);
    ctx.stroke();
}

/*
    Draw the clock face
*/
function drawClock()
{
    let angle;
    let pct;
    let x, y, x2, y2;
    let ctx = clockInfo.ctx;
    ctx.save();
    ctx.beginPath();
    ctx.fillStyle = "#fff";
    ctx.fillRect(0, 0, clockInfo.width, clockInfo.height);

    ctx.strokeStyle = "#000"; // the outer circle of the clock
    ctx.lineWidth = 2;
    ctx.beginPath();
    ctx.arc(clockInfo.width/2, clockInfo.height/2, clockInfo.radius, 0, Math.PI * 2, true);
    ctx.stroke();
    
    for (let i = 0; i < 12; i++) {
        ctx.beginPath();
        ctx.translate(clockInfo.width / 2, clockInfo.height / 2);
        ctx.rotate(toRadians(30.0 * i));
        ctx.moveTo(clockInfo.radius, 0);
        ctx.lineTo(clockInfo.radius - 4, 0);
        ctx.stroke();
        ctx.setTransform(1, 0, 0, 1, 0, 0);
    }
    
    ctx.lineWidth = 2; // draw the hour and minute hands
    hand(clockInfo.radius * 0.7, -90 + (clockInfo.hour + clockInfo.minute / 60) * 30);
    hand(clockInfo.radius * 0.9, -90 + clockInfo.minute * 6);
    
    ctx.fillStyle = "#080" // green dot at center of clock
    ctx.beginPath();
    ctx.arc(clockInfo.width / 2, clockInfo.height / 2, 4, 0, Math.PI * 2, true);
    ctx.fill();
}
